
import static org.junit.Assert.assertSame;

import org.infinispan.Cache;
import org.infinispan.configuration.cache.CacheMode;
import org.infinispan.configuration.cache.ConfigurationBuilder;
import org.infinispan.configuration.global.GlobalConfigurationBuilder;
import org.infinispan.manager.DefaultCacheManager;
import org.infinispan.notifications.Listener;
import org.infinispan.notifications.cachelistener.annotation.CacheEntryModified;
import org.infinispan.notifications.cachelistener.event.CacheEntryModifiedEvent;
import org.junit.Before;
import org.junit.Test;

public class SampleTest {
	
	private Cache<String, String> cache;
	
	@Listener
	public class MyListener {
		@CacheEntryModified
		public void entryUpdated(CacheEntryModifiedEvent<String, String> event) {
			if(!event.isPre()) {
				assertSame(event.getValue(), cache.get(event.getKey()));
			}
		}
	}
	
	@Before
	public void setup() throws Exception {
		DefaultCacheManager cacheManager = new DefaultCacheManager(GlobalConfigurationBuilder.defaultClusteredBuilder().transport()
				.build(), new ConfigurationBuilder().clustering().cacheMode(CacheMode.REPL_SYNC).sync().build());

		cache = cacheManager.getCache();
	}


	@Test
	public void must_notify_listeners_after_change_has_been_applied() {
		cache.addListener(new MyListener());
		cache.put("a", "a");
	}
}
